@@ -4,7 +4,7 @@ test_that("bank_slopes runs", {
   x <- 1:5
   y <- runif(length(x))
   out <- bank_slopes(x, y)
-  expect_equal(length(out), 1L)
+  expect_eqNe(length(out), 1L)
   expect_is(out, "numeric")
 })
 
@@ -12,7 +12,7 @@ test_that("bank_slopes with method=\"as\" runs", {
   x <- 1:5
   y <- runif(length(x))
   out <- bank_slopes(x, y, method = "as")
-  expect_equal(length(out), 1L)
+  expect_eqNe(length(out), 1L)
   expect_is(out, "numeric")
 })
 
@@ -24,6 +24,6 @@ test_that("bank_slopes works with cull = TRUE", {
   x <- c(1, 1, 2)
   y <- runif(length(x))
   out <- bank_slopes(x, y, cull = TRUE)
-  expect_equal(length(out), 1L)
+  expect_eqNe(length(out), 1L)
   expect_is(out, "numeric")
 })
