@@ -24,7 +24,7 @@ test_that("scale_colour_canva works", {
 })
 
 test_that("scale_color_canva works", {
-  expect_equal(scale_color_canva(), scale_colour_canva())
+  expect_eqNe(scale_color_canva(), scale_colour_canva())
 })
 
 test_that("scale_colour_canva works", {
